@@ -43,7 +43,7 @@ A repoze.who plugin for authentication via BrowserID:
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 0
+__ver_patch__ = 1
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__, __ver_minor__, __ver_patch__, __ver_sub__)
 __version__ = "%d.%d.%d%s" % __ver_tuple__
@@ -303,7 +303,7 @@ class BrowserIDPlugin(object):
         # Verify the assertion and extract data into the identity.
         try:
             data = self.verifier.verify(assertion)
-        except Exception, e:
+        except Exception:
             msg = "Invalid BrowserID assertion"
             environ[_ENVKEY_ERROR_MESSAGE] = msg
             self._rechallenge_at_postback(request)
@@ -420,7 +420,7 @@ def make_plugin(audiences, rememberer_name=None, postback_url=None,
                 if key == "verifier_urlopen":
                     value = resolveDotted(value)
                 if key.startswith("verifier_"):
-                    verifier_kwds[key[len("verifier_"):]] = value 
+                    verifier_kwds[key[len("verifier_"):]] = value
             verifier = verifier(**verifier_kwds)
     if isinstance(check_https, basestring):
         check_https = str2bool(check_https)
